function [sys,E]=EpLin(pendiente,m,varargin)
% EpLin determina las energías de los estados ligados de un objeto físico que 
%   interactúa con una energía potencial lineal de pendiente a (Ep = a*x). 
%
%   [sys,E]=EpLin(slope,m,varargin) 
%					-- varargin indica varios argumentos de entrada.
%   >> pendiente   	= Pendiente de la energía potencial (J/m)
%   >> m        	= Masa del objeto físico (respecto a la del electrón)
%   >> varargin  	= Argumentos de entrada opcionales:
%        >> nx   	= Número de puntos en el eje Ox (defecto: 100)
%        >> nE   	= Número de valores de energía (defecto: 1000)
%        >> Emin 	= Valor inferior de la energía (defecto: min(Ep))
%        >> Emax 	= Valor superior de la energía (defecto: Ep(max(x)))
%   
% Olivier Pujol (2010)

%% Verificaciones

if (length(varargin)>4), error('¡Número incorrecto de argumentos opcionales de entrada!');end
if (nargin-length(varargin)~=2),error('Número incorrecto de argumentos no opcionales de entrada!');end
if (pendiente<=realmin),error('¡Pendiente es cero!');end

%% Constantes y conversiones. 
%% Longitud característica. Conversión de la pendiente en eV/nm

% Constantes
h=6.6260755E-34;    % Constante de Planck (J.s)
hbar=h/(2*pi);
eV=1.60217733E-19;  % Electronvolt (J) 
me=0.91093897E-30;  % Masa del electrón (kg)

Lc=(hbar^2/(2*m*me*abs(pendiente)))^(1/3);   	% Longitud característica (en m)
Lc=1E9*Lc;                      	    		% Conversión en nanometro

pendiente=1E-9*pendiente/eV;                 	% Pendiente J/m --> eV/nm

%% Argumentos de entrada opcionales

switch length(varargin)
    case 0
        nx=100;                     % Valor por defecto del número de puntos en Ox
        nE=1000;                    % Valor por defecto del número de valores de energía
    case 1
        nx=varargin{1};             % Valor por defecto del número de puntos en Ox
        nE=1000;                    % Valor por defecto del número de valores de energía
    case 2
        nx=varargin{1};             % Valor por defecto del número de puntos en Ox
        nE=varargin{2};             % Valor por defecto del número de valores de energía
    case 4
        nx=varargin{1};             
        nE=varargin{2};             
        E=linspace(varargin{3},varargin{4},nE);     % Vector de los valores de la energía
    otherwise
        ('¡Número incorrecto de argumentos opcionales de entrada!');
end

%% Energía potencial

% Construcción
x=linspace(0,10*Lc,nx);     	% Intervalo espacial 
Epc=pendiente*x;                % Energía potencial lineal (pendiente en eV/nm)

% Digitalización
[M,xt,Ep]=digitalización(x,Epc); % Digitalización

% Si la pendiente es positiva, un nuevo escalón, M0, de altura 100*Ep(end)  
% se coloca en xt=0. Si la pendiente es negativa, el escalón M0 se coloca en
% xt=max(x); la altura del escalón es 100*abs(Ep(end)). 

if (pendiente>0)
    M=['M0' M];                             
    xt=[0;xt];
    Ep=[100*Ep(end);Ep];
end
if (pendiente<0)
   M=[M 'M0'];                             
   xt=[xt;max(x)];
   Ep=[Ep;100*abs(Ep(end))];
end 

% Valores de la energía
if (length(varargin)~=4)
    if (pendiente>0),E=linspace(min(Ep),Ep(end),nE);end
    if (pendiente<0),E=linspace(min(Ep),0,nE);end
end    

if (pendiente>0 && max(E)>Ep(end)),error('¡Algunos valores de E están fuera del dominio de los estados ligados!');end
if (pendiente<0 && max(E)>0),error('¡Algunos valores de E están fuera del dominio de los estados ligados!');end

%% Estados ligados (o confinados)

[sys,E]=Epot(M,xt,Ep,m,E);          % Sistema
sisconf(sys,E);                     % Estados ligados (o confinados)

return;