function [sys,E]=Hydrog(Z,l,m,varargin)
% Hydrog determina las energías de los estados ligados de un objeto físico 
%  confinado en la energía potencial de un ión hidrogenoide .
%
%  [sys,E]=Hydrog(Z,l,m,varargin) 
%                              -- varargin indica varios argumentos de entrada
%   	>> Z         = Número de carga del ión hidrogenoide
%   	>> l	       = Número cuántico secundario (l > 0)
%   	>> m         = Masa del objeto físico (respecto a la del electrón)
%   	>> varargin  = Argumentos de entrada opcionales
%         >> nx    = Número de bines en el eje Ox (defecto: 200)
%         >> nE    = Número de valores de energía (defecto: 1000)
%         >> Emin  = Valor inferior de la energía (defecto: min(Ep))
%         >> Emax  = Valor superior de la energía (defecto: 0)
%
% Olivier Pujol (2010)

%% Verificaciones

if (l==0),error('Este ejemplo funciona sólo si l > 0');end
if (Z<=0),error('Se debe tener Z >= 1');end

%% Argumentos opcionales de entrada

switch length(varargin)
    case 0
        nx=200;                     % Valor por defecto del número de puntos en Ox
        nE=1000;                    % Valor por defecto del número de valores de la energía
    case 1
        nx=varargin{1};             % Valor por defecto del número de puntos en Ox
        nE=1000;                    % Valor por defecto del número de valores de la energía
    case 2
        nx=varargin{1};             % Valor por defecto del número de puntos en Ox
        nE=varargin{2};             % Valor por defecto del número de valores de la energía
    case 4
        nx=varargin{1};             % Valor del número de puntos en Ox
        nE=varargin{2};             % Valor del número de valores de la energía
        E=linspace(varargin{3},varargin{4},nE);              % Vector de los valores de la energía
    otherwise
        ('¡Número incorrecto de argumentos opcionales de entrada!');
end

%% Energía potencial

% Constantes
Ry = 13.6058;                       % Rydberg (eV)
aB = 0.0529177;                     % Rayo de Bohr (nm)

Ep0 = Z^2*Ry/(l*(l+1));             % Mínimo de la energía potencial
x0 = l*(l+1)*aB/Z;                  % Punto correspondiente 

% Construcción
x=linspace(x0/4,50*x0,nx);          % Intervalo espacial
Epc=2*Ep0.*(-(x0./x)+(x0^2./(2.*x.^2)));     % Energías potenciales coulombiana + centrifuga. El origen es el mínimo

% Digitalización
[M,xt,Ep]=digitalización(x,Epc); 
axis([0 50*x0 min(Epc) 0]);			% Ejes del gráfico

clear Ry aB Ep0 Epc x

% Valores de la energía
if (length(varargin)~=4)
    E=linspace(min(Ep),Ep(end),nE);   % Vector de los valores de la energía
end    

if (max(E)>0),error('Algunos valores de la energía no están en el dominio de los estados ligados');end

%% Estados ligados (o confinados)

[sys,E]=Epot(M,xt,Ep,m,E);          % Sistema 
sisconf(sys,E);                     % Estados ligados (o confinados)

return;